## Minimal example

```py
--8<-- "docs/examples/basic_use/main.py"
```

### async python
The ```get_feature_service``` helper is running async, same for the get features methods
so there is no need to use async, but you could if you want 😊.

```py
--8<-- "docs/examples/basic_use/async_main.py"
```

